==> next-1.26.32.tgz: package/es/locale/id-id.js <==
export default {
    momentLocale: 'id',
    Timeline: {
        expand: 'Lebih Banyak',
        fold: 'Lebih Sedikit'
    },
    Balloon: {
        close: 'Tutup'
    },
    Card: {
        expand: 'Lebih Banyak',
        fold: 'Lebih Sedikit'
    },

    Calendar: {
        today: 'Hari Ini',
        now: 'Sekarang',
        ok: 'OK',
        clear: 'Reset',
        month: 'Bulan',
        year: 'Tahun',
        prevYear: 'Tahun Lalu',
        nextYear: 'Tahun Depan',
        prevMonth: 'Bulan Lalu',
        nextMonth: 'Bulan Depan',
        prevDecade: 'Sepuluh Tahun Sebelumnya',
        nextDecade: 'Sepuluh Tahun Selanjutnya',
        yearSelectAriaLabel: 'Tahun pilihan',
        monthSelectAriaLabel: 'Bulan pilihan'
    },
    DatePicker: {
        placeholder: 'Pilih Tanggal',
        datetimePlaceholder: 'Pilih Tanggal dan Waktu',
        monthPlaceholder: 'Pilih Bulan',
        yearPlaceholder: 'Pilih Tahun',
        weekPlaceholder: 'Pilih Minggu',
        now: 'Sekarang',
        selectTime: 'Pilih Waktu',
        selectDate: 'Pilih Tanggal',
        ok: 'OK',
        clear: 'Reset',
        startPlaceholder: 'Tanggal Mulai',
        endPlaceholder: 'Tanggal Selesai',
        hour: 'Jam',
        minute: 'Menit',
        second: 'Detik'
    },
    Dialog: {
        close: 'Tutup',
        ok: 'OK',
        cancel: 'Batalkan'
    },
    Drawer: {
        close: 'Tutup'
    },
    Message: {
        closeAriaLabel: 'Tutup'
    },
    Pagination: {
        prev: 'Sebelumnya',
        next: 'Selanjutnya',
        goTo: 'Ke Halaman',
        page: 'Halaman',
        go: 'Lihat',
        total: 'Halaman {current}, Total {total} Halaman',
        labelPrev: 'Halaman Sebelumnya, Halaman {current}',
        labelNext: 'Halaman Selanjutnya, Halaman {current}',
        inputAriaLabel: 'Masukkan halaman yang ingin dikunjungi',
        selectAriaLabel: 'Pilih jumlah yang ingin ditampilkan per halaman',
        pageSize: 'Jumlah setiap halaman:'
    },
    Input: {
        clear: 'Reset'
    },
    List: {
        empty: 'Tidak Ada Data'
    },
    Select: {
        selectPlaceholder: 'Silakan Pilih',
        autoCompletePlaceholder: 'Silakan Masukkan',
        notFoundContent: 'Konten Tidak Ditemukan',
        maxTagPlaceholder: '{selected} / {total} Dipilih',
        selectAll: 'Pilih Semua'
    },
    TreeSelect: {
        maxTagPlaceholder: '{selected} / {total} Dipilih',
        shortMaxTagPlaceholder: '{selected} Dipilih'
    },
    Table: {
        empty: 'Tidak Ada Data',
        ok: 'OK',
        reset: 'Reset',
        asc: 'Kecil ke Besar',
        desc: 'Besar ke Kecil',
        expanded: 'Lebih Banyak',
        folded: 'Lebih Sedikit',
        filter: 'Filter',
        selectAll: 'Pilih Semua'
    },
    TimePicker: {
        placeholder: 'Silakan Pilih',
        clear: 'Reset',
        hour: 'Jam',
        minute: 'Menit',
        second: 'Detik',
        ok: 'OK'
    },
    Transfer: {
        items: 'barang',
        item: 'barang',
        moveAll: 'Pindahkan Semua.',
        searchPlaceholder: 'Silakan Masukkan',
        moveToLeft: 'Batalkan Pilihan',
        moveToRight: 'Simpan'
    },
    Upload: {
        card: {
            cancel: 'Batalkan',
            addPhoto: 'Tambah Gambar',
            download: 'Download',
            delete: 'Hapus'
        },
        drag: {
            text: 'Klik atau drag file untuk upload',
            hint: 'Tipe file yang didukung: DOCX, XLS, PDF, RAR, ZIP, PNG, JPG'
        },
        upload: {
            delete: 'Hapus'
        }
    },
    Search: {
        buttonText: 'Cari'
    },
    Tag: {
        delete: 'Hapus'
    },
    Rating: {
        description: 'Peringkat'
    },
    Switch: {
        on: 'Aktif',
        off: 'Non-Aktif'
    },
    Tab: {
        closeAriaLabel: 'Tutup'
    },
    Form: {
        Validate: {
            default: 'Validasi %s gagal',
            required: '%s wajib diisi',
            format: {
                number: '%s tidak valid',
                email: '%s tidak valid',
                url: '%s tidak valid',
                tel: '%s tidak valid'
            },
            number: {
                length: 'Panjang %s harus %s',
                min: '%s minimum %s',
                max: '%s maksimum %s',
                minLength: '%s maksimum %s',
                maxLength: '%s minimum %s'
            },
            string: {
                length: 'Panjang %s harus %s',
                min: '%s minimum %s',
                max: '%s maksimum %s',
                minLength: '%s maksimum %s',
                maxLength: '%s minimum %s'
            },
            array: {
                length: 'Panjang %s harus %s',
                minLength: '%s minimum %s',
                maxLength: '%s maksimum %s'
            },
            pattern: ' Value %s %s tidak cocok dengan pattern %s'
        }
    }
};

==> next-1.27.17.tgz: package/es/locale/id-id.js <==
var locale = {
    momentLocale: 'id',
    Timeline: {
        expand: 'Lebih Banyak',
        fold: 'Lebih Sedikit',
    },
    Balloon: {
        close: 'Tutup',
    },
    Card: {
        expand: 'Lebih Banyak',
        fold: 'Lebih Sedikit',
    },
    Calendar: {
        today: 'Hari Ini',
        now: 'Sekarang',
        ok: 'OK',
        clear: 'Reset',
        month: 'Bulan',
        year: 'Tahun',
        prevYear: 'Tahun Lalu',
        nextYear: 'Tahun Depan',
        prevMonth: 'Bulan Lalu',
        nextMonth: 'Bulan Depan',
        prevDecade: 'Sepuluh Tahun Sebelumnya',
        nextDecade: 'Sepuluh Tahun Selanjutnya',
        yearSelectAriaLabel: 'Tahun pilihan',
        monthSelectAriaLabel: 'Bulan pilihan',
    },
    DatePicker: {
        placeholder: 'Pilih Tanggal',
        datetimePlaceholder: 'Pilih Tanggal dan Waktu',
        monthPlaceholder: 'Pilih Bulan',
        yearPlaceholder: 'Pilih Tahun',
        weekPlaceholder: 'Pilih Minggu',
        now: 'Sekarang',
        selectTime: 'Pilih Waktu',
        selectDate: 'Pilih Tanggal',
        ok: 'OK',
        clear: 'Reset',
        startPlaceholder: 'Tanggal Mulai',
        endPlaceholder: 'Tanggal Selesai',
        hour: 'Jam',
        minute: 'Menit',
        second: 'Detik',
        monthBeforeYear: false,
    },
    Dialog: {
        close: 'Tutup',
        ok: 'OK',
        cancel: 'Batalkan',
    },
    Drawer: {
        close: 'Tutup',
    },
    Message: {
        closeAriaLabel: 'Tutup',
    },
    Pagination: {
        prev: 'Sebelumnya',
        next: 'Selanjutnya',
        goTo: 'Ke Halaman',
        page: 'Halaman',
        go: 'Lihat',
        total: 'Halaman {current}, Total {total} Halaman',
        labelPrev: 'Halaman Sebelumnya, Halaman {current}',
        labelNext: 'Halaman Selanjutnya, Halaman {current}',
        inputAriaLabel: 'Masukkan halaman yang ingin dikunjungi',
        selectAriaLabel: 'Pilih jumlah yang ingin ditampilkan per halaman',
        pageSize: 'Jumlah setiap halaman:',
    },
    Input: {
        clear: 'Reset',
    },
    TextArea: {
        clear: 'Reset',
    },
    List: {
        empty: 'Tidak Ada Data',
    },
    Select: {
        selectPlaceholder: 'Silakan Pilih',
        autoCompletePlaceholder: 'Silakan Masukkan',
        notFoundContent: 'Konten Tidak Ditemukan',
        maxTagPlaceholder: '{selected} / {total} Dipilih',
        selectAll: 'Pilih Semua',
    },
    TreeSelect: {
        maxTagPlaceholder: '{selected} / {total} Dipilih',
        shortMaxTagPlaceholder: '{selected} Dipilih',
    },
    Table: {
        empty: 'Tidak Ada Data',
        ok: 'OK',
        reset: 'Reset',
        asc: 'Kecil ke Besar',
        desc: 'Besar ke Kecil',
        expanded: 'Lebih Banyak',
        folded: 'Lebih Sedikit',
        filter: 'Filter',
        selectAll: 'Pilih Semua',
    },
    TimePicker: {
        placeholder: 'Silakan Pilih',
        clear: 'Reset',
        hour: 'Jam',
        minute: 'Menit',
        second: 'Detik',
        ok: 'OK',
    },
    Transfer: {
        items: 'barang',
        item: 'barang',
        moveAll: 'Pindahkan Semua.',
        searchPlaceholder: 'Silakan Masukkan',
        moveToLeft: 'Batalkan Pilihan',
        moveToRight: 'Simpan',
    },
    Upload: {
        card: {
            cancel: 'Batalkan',
            addPhoto: 'Tambah Gambar',
            download: 'Download',
            delete: 'Hapus',
        },
        drag: {
            text: 'Klik atau drag file untuk upload',
            hint: 'Tipe file yang didukung: DOCX, XLS, PDF, RAR, ZIP, PNG, JPG',
        },
        upload: {
            delete: 'Hapus',
        },
    },
    Search: {
        buttonText: 'Cari',
    },
    Tag: {
        delete: 'Hapus',
    },
    Rating: {
        description: 'Peringkat',
    },
    Switch: {
        on: 'Aktif',
        off: 'Non-Aktif',
    },
    Tab: {
        closeAriaLabel: 'Tutup',
    },
    Form: {
        Validate: {
            default: 'Validasi %s gagal',
            required: '%s wajib diisi',
            format: {
                number: '%s tidak valid',
                email: '%s tidak valid',
                url: '%s tidak valid',
                tel: '%s tidak valid',
            },
            number: {
                length: 'Panjang %s harus %s',
                min: '%s minimum %s',
                max: '%s maksimum %s',
                minLength: '%s maksimum %s',
                maxLength: '%s minimum %s',
            },
            string: {
                length: 'Panjang %s harus %s',
                min: '%s minimum %s',
                max: '%s maksimum %s',
                minLength: '%s maksimum %s',
                maxLength: '%s minimum %s',
            },
            array: {
                length: 'Panjang %s harus %s',
                minLength: '%s minimum %s',
                maxLength: '%s maksimum %s',
            },
            pattern: ' Value %s %s tidak cocok dengan pattern %s',
        },
    },
};
export default locale;
